==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>Mostrar os comandos de manipulación de lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>Amosar tódalas listas de reprodución dispoñibles</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>Amosar o contido da lista</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Reproducir a pista &lt;track&gt; na lista &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>Limpar lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Toggle playlist repeat</source>
        <translation>Activar repetición de lista</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Toggle playlist shuffle</source>
        <translation>Activar orde aleatoria</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Show playlist options</source>
        <translation>Amosar opcións de lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <location filename="../playlistoption.cpp" line="126"/>
        <location filename="../playlistoption.cpp" line="143"/>
        <source>Invalid playlist ID</source>
        <translation>ID de lista de reprodución non válida</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="120"/>
        <source>Invalid number of arguments</source>
        <translation>Número de argumentos non válido</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="130"/>
        <source>Invalid track ID</source>
        <translation>ID de pista non válido</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>Mostrar os comandos de manipulación de lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>Amosar tódalas listas de reprodución dispoñibles</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>Amosar o contido da lista</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Reproducir a pista &lt;track&gt; na lista &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>Limpar lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Activate next playlist</source>
        <translation>Activala seguinte lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Activate previous playlist</source>
        <translation>Activala anterior lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Toggle playlist repeat</source>
        <translation>Activar repetición de lista</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="41"/>
        <source>Toggle playlist shuffle</source>
        <translation>Activar orde aleatoria</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="42"/>
        <source>Show playlist options</source>
        <translation>Amosar opcións de lista de reprodución</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="110"/>
        <location filename="../playlistoption.cpp" line="132"/>
        <location filename="../playlistoption.cpp" line="171"/>
        <source>Invalid playlist ID</source>
        <translation>ID de lista de reprodución non válida</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="126"/>
        <source>Invalid number of arguments</source>
        <translation>Número de argumentos non válido</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="136"/>
        <source>Invalid track ID</source>
        <translation>ID de pista non válido</translation>
    </message>
</context>
</TS>
